## Dataset Attribution
This dataset was created by Zhao et al and is licensed under the Creative Commons Attribution 4.0 International.

- Original Source: [aclanthology.org](https://aclanthology.org/N18-2003/)
- License: [https://creativecommons.org/licenses/by/4.0/](https://creativecommons.org/licenses/by/4.0/)
- Data from Table 1 were extracted. Plural terms were changed to singular.
